from datasets import load_dataset
import pandas as pd
from transformers import AutoTokenizer, AutoModelForCausalLM
import os

#os.environ['HF_ENDPOINT'] = 'https://hf-mirror.com'  # 使用镜像站点
# 设置数据集的缓存目录
dataset_cache_dir = "./Datasets/"
# 指定本地保存路径
local_save_path = "./Datasets/evol_instruct_data.json"
# 设置模型缓存目录
local_model_dir = './Model/'
# 设置模型名称
model_name = "deepseek-ai/deepseek-coder-6.7b-instruct"
# 下载数据集并指定缓存目录
dataset = load_dataset("nickrosh/Evol-Instruct-Code-80k-v1", data_files="EvolInstruct-Code-80k.json", cache_dir=dataset_cache_dir)
# 获取训练数据（假设数据集是按拆分存储的）
train_data = dataset["train"]

# 将数据转换为 Pandas DataFrame
df = pd.DataFrame(train_data)

# 将 DataFrame 保存为 JSON 文件
df.to_json(local_save_path, orient="records", lines=True)

# 打印确认信息
print(f"Dataset saved to {local_save_path}.")

# 下载并加载 tokenizer 和模型
tokenizer = AutoTokenizer.from_pretrained(model_name, cache_dir=local_model_dir)
model = AutoModelForCausalLM.from_pretrained(model_name, cache_dir=local_model_dir)

# 打印确认信息
print(f"Model and tokenizer downloaded and cached in '{local_model_dir}'.")
print(f"Dataset downloaded and cached in '{dataset_cache_dir}'.")

